@@ -1,3 +1,6 @@
+# -*- coding: utf-8 -*-
+"""Various encryption utilites."""
+
 import base64
 import zlib
 import struct
@@ -5,6 +8,7 @@ from Crypto.Cipher import AES
 
 
 class CheckSumError(Exception):
+    """Checksum mismatch error class."""
     pass
 
 
@@ -15,17 +19,18 @@ def _lazysecret(secret, blocksize=32, padding='}'):
     return secret
 
 
-def encrypt(plaintext, secret, iv, checksum=True, lazy=True):
+def encrypt(plaintext, secret, inital_vector, checksum=True, lazy=True):
     """Encrypts plaintext with secret
-    plaintext   - content to encrypt
-    secret      - secret to encrypt plaintext
-    lazy        - pad secret if less than legal blocksize (default: True)
-    checksum    - attach crc32 byte encoded (default: True)
+    plaintext      - content to encrypt
+    secret         - secret to encrypt plaintext
+    inital_vector  - initial vector
+    lazy           - pad secret if less than legal blocksize (default: True)
+    checksum       - attach crc32 byte encoded (default: True)
     returns ciphertext
     """
 
     secret = _lazysecret(secret) if lazy else secret
-    encobj = AES.new(secret, AES.MODE_CFB, iv)
+    encobj = AES.new(secret, AES.MODE_CFB, inital_vector)
 
     if checksum:
         plaintext += base64.urlsafe_b64encode(
@@ -34,17 +39,18 @@ def encrypt(plaintext, secret, iv, checksum=True, lazy=True):
     return base64.urlsafe_b64encode(encobj.encrypt(plaintext)).replace('=', '')
 
 
-def decrypt(ciphertext, secret, iv, checksum=True, lazy=True):
+def decrypt(ciphertext, secret, inital_vector, checksum=True, lazy=True):
     """Decrypts ciphertext with secret
-    ciphertext  - encrypted content to decrypt
-    secret      - secret to decrypt ciphertext
-    lazy        - pad secret if less than legal blocksize (default: True)
-    checksum    - verify crc32 byte encoded checksum (default: True)
+    ciphertext     - encrypted content to decrypt
+    secret         - secret to decrypt ciphertext
+    inital_vector  - initial vector
+    lazy           - pad secret if less than legal blocksize (default: True)
+    checksum       - verify crc32 byte encoded checksum (default: True)
     returns plaintext
     """
 
     secret = _lazysecret(secret) if lazy else secret
-    encobj = AES.new(secret, AES.MODE_CFB, iv)
+    encobj = AES.new(secret, AES.MODE_CFB, inital_vector)
     plaintext = encobj.decrypt(base64.urlsafe_b64decode(
         ciphertext + ('=' * (len(ciphertext) % 4))))
 
